# -*- coding: utf-8 -*-
### BEGIN LICENSE
# Copyright (C) Canonical Inc.  <Alexander Wolfson> <alex.wolfson@canonical.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE
import time
import subprocess, shlex, traceback
OK,COMMAND_ERROR,TIMEOUT = 0, -1, -2
class AppTimer(object):
    '''
    Core GUI independent functionality.
    '''
    def __init__(self):
        pass
    def setCursor(self, size):
        pass
    def getScreenArea(self):
        pass;
    def compareScreenArea(self):
        return False
    def showStatus(self, msg):
        print msg
    def schedule_timer(period, argumets):
        pass
    def check_screen(self, process_status, time_dead_line):
        ''' This function checks  if screen is in desired state
        return: True if we still needs to continue to check, False otherwise'''
        if time.time() >= time_dead_line:
            self.showStatus ("Timeout at %f sec from start for '%s' " % (time.time() - self.start_time, self.command_line))
            self.is_timeout=True
            return False
        stat = process_status.poll()
        if self.compareScreenArea():
            self.showStatus ("It took %f sec for '%s' to reach the desired state" % (time.time() - self.start_time, self.command_line))
            self.is_timeout=False
            return False
        if stat == None: #process is still running
            return True
        else:
            if self.first_run == True:
                self.showStatus ("It took %f sec for '%s' to finish with status %d" % (time.time() - self.start_time, self.command_line, stat))
                self.first_run = False
                self.is_timeout=False
            return True  # we still continue to watch
    def run(self, command_line):
        ''' Loop with time_resolution(0.1 sec) precision, checking for an area on the screeen to be equal the preset value'''
        self.command_line = command_line
        if command_line != None:
            args = shlex.split(command_line)
            try:
                self.start_time=time.time()
                p = subprocess.Popen(args) 
            except IndexError as exc:
                self.showStatus ("Apptimer.run(): Trying to execute an empty command")
                traceback.print_exc()
                return COMMAND_ERROR
            except OSError as exc:
                self.showStatus ("Apptimer.run():" + exc.strerror + ". Trying to execute a nonexisting command (%s)" % ' '.join(args))
                traceback.print_exc()
                return COMMAND_ERROR
            except Exception as exc:
                self.showStatus ("Apptimer.run():" + str(exc)) 
                traceback.print_exc()
                return COMMAND_ERROR
            else:
                return p
        else:
            return COMMAND_ERROR
if __name__ == "__main__":
    t = AppTimer()
    t.run(0.01, "ls /")
    t = AppTimer()
    t.run(1.0, "ls @#$%^")
    t = AppTimer()
    t.run(1.0, "ls /")
    t = AppTimer()
    t.run(1.0, "NON_EXISTING")
